==> jc-1.4.0.tar.gz: soot/jimple/toolkits/pointer/SideEffectTagger__241.h <==
// class soot.jimple.toolkits.pointer.SideEffectTagger$1

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 56d5c6fc0a4b0110 soot_jimple_toolkits_pointer_SideEffectTagger__241
// @dep_class d2eacdeb35392377 soot_jimple_toolkits_pointer_UnionFactory

// header file dependencies
// @dep_header soot_jimple_toolkits_pointer_UnionFactory

#include "soot/jimple/toolkits/pointer/UnionFactory.h"

#ifndef _JC_soot_jimple_toolkits_pointer_SideEffectTagger__241_H_
#define _JC_soot_jimple_toolkits_pointer_SideEffectTagger__241_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$object;
struct _jc_soot_jimple_toolkits_pointer_Union$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$sub_refs	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$refs	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$nonrefs	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$object	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$vmethods	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$vtable	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$vtype	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$method$_init$d4751e1f0bea927c(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$object *, struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$object *);

// Virtual methods
extern struct _jc_soot_jimple_toolkits_pointer_Union$object *_jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$method$newUnion$cadc46e7aeca770e(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$method_info$newUnion$cadc46e7aeca770e;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$vmethods {
	struct _jc_soot_jimple_toolkits_pointer_Union$object	*(*newUnion$cadc46e7aeca770e)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_UnionFactory$vmethods	soot_jimple_toolkits_pointer_UnionFactory;
	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$vmethods	soot_jimple_toolkits_pointer_SideEffectTagger__241;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$sub_refs {
	struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$refs {
    _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$sub_refs	soot_jimple_toolkits_pointer_SideEffectTagger__241;
    _jc_soot_jimple_toolkits_pointer_UnionFactory$sub_refs	soot_jimple_toolkits_pointer_UnionFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_UnionFactory$sub_nonrefs	soot_jimple_toolkits_pointer_UnionFactory;
    _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$sub_nonrefs	soot_jimple_toolkits_pointer_SideEffectTagger__241;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$object {
	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$vtype _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_SideEffectTagger__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_SideEffectTagger__241_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/pointer/SideEffectTagger__241.h <==
// class soot.jimple.toolkits.pointer.SideEffectTagger$1

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 56d5c6fc0a4b0110 soot_jimple_toolkits_pointer_SideEffectTagger__241
// @dep_class d2eacdeb35392377 soot_jimple_toolkits_pointer_UnionFactory

// header file dependencies
// @dep_header soot_jimple_toolkits_pointer_UnionFactory

#include "soot/jimple/toolkits/pointer/UnionFactory.h"

#ifndef _JC_soot_jimple_toolkits_pointer_SideEffectTagger__241_H_
#define _JC_soot_jimple_toolkits_pointer_SideEffectTagger__241_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$object;
struct _jc_soot_jimple_toolkits_pointer_Union$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$sub_refs	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$refs	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$nonrefs	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$object	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$vmethods	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$vtable	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$vtype	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$method$_init$d4751e1f0bea927c(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$object *, struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_soot_jimple_toolkits_pointer_Union$object *_jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$method$newUnion$cadc46e7aeca770e(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$method_info$newUnion$cadc46e7aeca770e;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$vmethods {
	struct _jc_soot_jimple_toolkits_pointer_Union$object	*(*newUnion$cadc46e7aeca770e)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_UnionFactory$vmethods	soot_jimple_toolkits_pointer_UnionFactory;
	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$vmethods	soot_jimple_toolkits_pointer_SideEffectTagger__241;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$sub_refs {
	struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$refs {
    _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$sub_refs	soot_jimple_toolkits_pointer_SideEffectTagger__241;
    _jc_soot_jimple_toolkits_pointer_UnionFactory$sub_refs	soot_jimple_toolkits_pointer_UnionFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_UnionFactory$sub_nonrefs	soot_jimple_toolkits_pointer_UnionFactory;
    _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$sub_nonrefs	soot_jimple_toolkits_pointer_SideEffectTagger__241;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$object {
	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$vtype _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_SideEffectTagger__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_SideEffectTagger__241$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_SideEffectTagger__241_H_ */
